# gopyadapter

## Development setup

- Install [uv](https://docs.astral.sh/uv/)
- Create a local virtual environment with `uv venv .venv`
- Install the project and dev dependencies with `uv sync --group dev`
- Activate the environment with `source .venv/bin/activate`

## Publishing

- Build distributions with `uv build`
- Publish with `uv publish`
